Crate rama_http

Crate rama_http 

rama http services, layers and utilities

Rama

Crate used by the end-user rama crate and rama crate authors alike.

Learn more about rama:

Modules

body
extra http body types and utilities.
conn
HTTP connection utilities.
convert
Modules for conversions between types or data.
fingerprint
HTTP fingerprint implementations (JA4H, Akamai HTTP/2).
header
Forked from the http crate — vendored so rama owns its HTTP header types. See docs/thirdparty/fork/README.md. The fork-style lint allows below also cover the name/value/map child modules.
headers
Typed HTTP Headers
io
http I/O utilities, e.g. writing http requests/responses in std http format.
layer
Http Layers provided by Rama.
matcher
service::Matchers implementations to match on rama_http_types::Requests.
method
Forked from the http crate — vendored so rama owns its HTTP leaf types. See docs/thirdparty/fork/README.md.
mime
Re-export of the mime crate.
opentelemetry
Opentelemetry utilities
proto
High level pertaining to the HTTP message protocol.
protocols
Protocols that are often built on top of HTTP.
request
response
service
Http Services provided by Rama.
sse
Server-Sent Events (SSE) support
status
Forked from the http crate — vendored so rama owns its HTTP leaf types. See docs/thirdparty/fork/README.md.
utils
Utilities for HTTP.
version
HTTP version type, owned by rama-net.

Structs

Body
The body type used in rama requests and responses.
BodyDataStream
A stream of data frames.
BodyLimit
Can be used to communicate the desire to limit the size of request/response bodies.
BodyLimitLayer
Limit the size of the request and/or response bodies.
BodyLimitService
Communicate to the downstream http service to apply a limit to the body.
HeaderMap
A specialized multimap for header names and values.
HeaderName
Represents an HTTP header field name
HeaderValue
Represents an HTTP header field value.
HttpError
A generic “error” for HTTP connections.
InfiniteReader
A(n) (in)finite random byte stream implementing AsyncRead.
Method
The Request Method (VERB)
Request
Represents an HTTP request.
Response
Represents an HTTP response
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
Version
Represents a version of the HTTP spec.

Traits

BodyExtractExt
An extension trait for StreamingBody that provides methods to extract data from it.
StreamingBody
Trait representing a streaming body of a Request or Response.

Type Aliases

HttpResult
A Result typedef to use with the Error type.