pub struct TargetHttpVersion(pub Version);Expand description
Target http version
This can be set manually to enforce a specific version, otherwise this will be set automatically by things such tls alpn
Tuple Fields
0: VersionTrait Implementations
Sourceimpl Clone for TargetHttpVersion
impl Clone for TargetHttpVersion
Sourcefn clone(&self) -> TargetHttpVersion
fn clone(&self) -> TargetHttpVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TargetHttpVersion
Sourceimpl Debug for TargetHttpVersion
impl Debug for TargetHttpVersion
Sourceimpl Default for TargetHttpVersion
impl Default for TargetHttpVersion
Sourcefn default() -> TargetHttpVersion
fn default() -> TargetHttpVersion
Returns the “default value” for a type. Read more
impl Eq for TargetHttpVersion
impl Extension for TargetHttpVersion
impl HttpExtension for TargetHttpVersion
Sourceimpl PartialEq for TargetHttpVersion
impl PartialEq for TargetHttpVersion
Sourcefn eq(&self, other: &TargetHttpVersion) -> bool
fn eq(&self, other: &TargetHttpVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TargetHttpVersion