Module encoding

Module encoding 

Utility types and functions that can be used in context of encoding headers.

Structs

AcceptEncoding
TODO: support this as typed header…

Enums

Encoding
This enum’s variants are ordered from least to most preferred.

Traits

SupportedEncodings

Functions

maybe_preferred_encoding_with_wildcard
Selects the preferred encoding while honoring the * wildcard per RFC 9110 12.5.3.
parse_accept_encoding_headers
based on https://github.com/http-rs/accept-encoding
parse_accept_encoding_wildcard_quality
Extracts the quality value of the * wildcard from Accept-Encoding headers.