Forwarded

Struct Forwarded 

pub struct Forwarded(/* private fields */);
Typed header wrapper for rama_net::forwarded::Forwarded;

Implementations

Source

impl Forwarded

pub fn into_inner(self) -> Forwarded

Return the inner Forwarded.

Methods from Deref<Target = Forwarded>

pub fn client_host(&self) -> Option<&ForwardedAuthority>

Return the client host of this Forwarded context, if there is one defined.

It is assumed that only the first element can be described as client information.

pub fn client_socket_addr(&self) -> Option<SocketAddress>

Return the client SocketAddress of this Forwarded context, if both an Ip and a port are defined.

You can try to fallback to Self::client_ip, in case this method returns None.

pub fn client_port(&self) -> Option<u16>

Return the client port of this Forwarded context, if there is one defined.

pub fn client_ip(&self) -> Option<IpAddr>

Return the client Ip of this Forwarded context, if there is one defined.

This method may return None because there is no forwarded “for” information for the client element or because the IP is obfuscated.

It is assumed that only the first element can be described as client information.

pub fn client_proto(&self) -> Option<ForwardedProtocol>

Return the client protocol of this Forwarded context, if there is one defined.

pub fn client_version(&self) -> Option<ForwardedVersion>

Return the client protocol version of this Forwarded context, if there is one defined.

pub fn append(&mut self, element: ForwardedElement) -> &mut Forwarded

Append a ForwardedElement to this Forwarded context.

pub fn extend( &mut self, elements: impl IntoIterator<Item = ForwardedElement>, ) -> &mut Forwarded

Extend this Forwarded context with the given ForwardedElements.

pub fn iter(&self) -> impl Iterator<Item = &ForwardedElement>

Iterate over the ForwardedElements in this Forwarded context.