pub struct Via(/* private fields */);Expand description
The Via general header is added by proxies, both forward and reverse.
This header can appear in the request or response headers. It is used for tracking message forwards, avoiding request loops, and identifying the protocol capabilities of senders along the request/response chain.
It is recommended to use the Forwarded header instead if you can.
More info can be found at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Via.
Syntax
Via: [ <protocol-name> "/" ] <protocol-version> <host> [ ":" <port> ]
Via: [ <protocol-name> "/" ] <protocol-version> <pseudonym>Example values
1.1 vegurHTTP/1.1 GWA1.0 fred, 1.1 p.example.netHTTP/1.1 proxy.example.re, 1.1 edge_11.1 2e9b3ee4d534903f433e1ed8ea30e57a.cloudfront.net (CloudFront)