SecGpc

Struct SecGpc 

#[non_exhaustive]
pub struct SecGpc;
The Sec-GPC header, or the Global Privacy Control header.

It is an HTTP response and request header used specifically to allow the user to communicate their privacy preferences to the server.

This enables the user to exercise control over the privacy of their personal information against tracking, data selling, or adverse uses.

Implementations

Source

impl SecGpc

pub fn new() -> SecGpc

Create a new SecGpc typed header.