#[non_exhaustive]pub struct AccessControlAllowPrivateNetwork;Expand description
Access-Control-Allow-Private-Network header, as documented in
this draft of WICG.
Not an official standard but widely used. This CORS header to allow a public origin make a cross site request to a server hosted on a private network (e.g. behind a firewall).
ABNF
Access-Control-Allow-Private-Network: "Access-Control-Allow-Private-Network" ":" "true"Since there is only one acceptable field value, the header struct does not accept
any values at all. Setting an empty AccessControlAllowPrivateNetwork header is
sufficient. See the examples below.
Example values
- “true”
Examples
use rama_http_headers::AccessControlAllowPrivateNetwork;
let allow_creds = AccessControlAllowPrivateNetwork::default();Implementations