pub struct AccessControlMaxAge(/* private fields */);Expand description
Access-Control-Max-Age header, as defined on
mdn.
The Access-Control-Max-Age header indicates how long the results of a
preflight request can be cached in a preflight result cache.
ABNF
Access-Control-Max-Age = \"Access-Control-Max-Age\" \":\" delta-secondsExample values
531
Examples
use rama_http_headers::AccessControlMaxAge;
let max_age = AccessControlMaxAge::from_seconds(531);Implementations
Sourceimpl AccessControlMaxAge
impl AccessControlMaxAge
pub fn from_seconds(secs: u64) -> AccessControlMaxAge
pub fn try_from_duration(dur: Duration) -> Option<AccessControlMaxAge>
pub fn from_duration_rounded(dur: Duration) -> AccessControlMaxAge
pub fn as_secs(self) -> u64