pub struct AccessControlRequestMethod(pub Method);Expand description
Access-Control-Request-Method header, as defined on
mdn.
The Access-Control-Request-Method header indicates which method will be
used in the actual request as part of the preflight request.
ABNF
Access-Control-Request-Method: \"Access-Control-Request-Method\" \":\" MethodExample values
GET
Examples
use rama_http_headers::AccessControlRequestMethod;
use rama_http_types::Method;
let req_method = AccessControlRequestMethod::from(Method::GET);Tuple Fields
0: MethodTrait Implementations
Sourceimpl Clone for AccessControlRequestMethod
impl Clone for AccessControlRequestMethod
Sourcefn clone(&self) -> AccessControlRequestMethod
fn clone(&self) -> AccessControlRequestMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccessControlRequestMethod
impl Debug for AccessControlRequestMethod
impl Eq for AccessControlRequestMethod
Sourceimpl From<AccessControlRequestMethod> for Method
impl From<AccessControlRequestMethod> for Method
Sourcefn from(method: AccessControlRequestMethod) -> Method
fn from(method: AccessControlRequestMethod) -> Method
Converts to this type from the input type.
Sourceimpl From<Method> for AccessControlRequestMethod
impl From<Method> for AccessControlRequestMethod
Sourcefn from(method: Method) -> AccessControlRequestMethod
fn from(method: Method) -> AccessControlRequestMethod
Converts to this type from the input type.
Sourceimpl Hash for AccessControlRequestMethod
impl Hash for AccessControlRequestMethod
Sourceimpl HeaderDecode for AccessControlRequestMethod
impl HeaderDecode for AccessControlRequestMethod
Sourcefn decode<'i, I>(values: &mut I) -> Result<AccessControlRequestMethod, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<AccessControlRequestMethod, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl HeaderEncode for AccessControlRequestMethod
impl HeaderEncode for AccessControlRequestMethod
Sourcefn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
fn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
Encode this type to a
HeaderValue, and add it to a container
which has HeaderValue type as each element. Read moreSourcefn encode_to_value(&self) -> Option<HeaderValue>
fn encode_to_value(&self) -> Option<HeaderValue>
Encode this header to
HeaderValue. Read moreSourceimpl PartialEq for AccessControlRequestMethod
impl PartialEq for AccessControlRequestMethod
Sourcefn eq(&self, other: &AccessControlRequestMethod) -> bool
fn eq(&self, other: &AccessControlRequestMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AccessControlRequestMethod
Sourceimpl TypedHeader for AccessControlRequestMethod
impl TypedHeader for AccessControlRequestMethod
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.