Age

Struct Age 

pub struct Age(/* private fields */);
Age header, defined in RFC7234

The “Age” header field conveys the sender’s estimate of the amount of time since the response was generated or successfully validated at the origin server. Age values are calculated as specified in Section 4.2.3.

ABNF

Age = delta-seconds

The Age field-value is a non-negative integer, representing time in seconds (see Section 1.2.1).

The presence of an Age header field implies that the response was not generated or validated by the origin server for this request. However, lack of an Age header field does not imply the origin was contacted, since the response might have been received from an HTTP/1.0 cache that does not implement Age.

Example values

  • 3600

Example

use rama_http_headers::Age;

let len = Age::from_seconds(60);

Implementations