ContentEncoding

Struct ContentEncoding 

pub struct ContentEncoding(pub NonEmptyVec<ContentEncodingDirective>);
Content-Encoding header, defined in RFC7231

The Content-Encoding header field indicates what content codings have been applied to the representation, beyond those inherent in the media type, and thus what decoding mechanisms have to be applied in order to obtain data in the media type referenced by the Content-Type header field. Content-Encoding is primarily used to allow a representation’s data to be compressed without losing the identity of its underlying media type.

ABNF

Content-Encoding = 1#content-coding

Example values

  • gzip
  • br
  • zstd
  • deflate, gzip

Examples

use rama_http_headers::ContentEncoding;

let content_enc = ContentEncoding::gzip();

Tuple Fields

0: NonEmptyVec<ContentEncodingDirective>

Implementations

Source

impl ContentEncoding

Source

impl ContentEncoding

pub fn new_multi( directives: NonEmptyVec<ContentEncodingDirective>, ) -> ContentEncoding

Create a new ContentEncoding header with multiple directives.

Meaning the content is encoded with all given directives and in order.

pub fn gzip() -> ContentEncoding

A constructor to easily create a Content-Encoding: gzip header.

pub fn brotli() -> ContentEncoding

A constructor to easily create a Content-Encoding: br header.

pub fn zstd() -> ContentEncoding

A constructor to easily create a Content-Encoding: zstd header.

pub fn contains_directive(&self, coding: impl CmpCoding) -> bool

Check if this header contains a given “coding”.

This can be used with these argument types:

  • &str
Example
use rama_http_headers::ContentEncoding;

let content_enc = ContentEncoding::gzip();

assert!(content_enc.contains_directive("gzip"));
assert!(!content_enc.contains_directive("br"));