pub struct Expires(/* private fields */);Expand description
Expires header, defined in RFC7234
The Expires header field gives the date/time after which the
response is considered stale.
The presence of an Expires field does not imply that the original resource will change or cease to exist at, before, or after that time.
ABNF
Expires = HTTP-dateExample values
Thu, 01 Dec 1994 16:00:00 GMT
Example
use rama_http_headers::Expires;
use rama_utils::time::now_system_time;
use std::time::Duration;
let time = now_system_time() + Duration::from_hours(24);
let expires = Expires::from(time);Trait Implementations
impl Copy for Expires
impl Eq for Expires
Sourceimpl From<SystemTime> for Expires
impl From<SystemTime> for Expires
Sourcefn from(time: SystemTime) -> Expires
fn from(time: SystemTime) -> Expires
Converts to this type from the input type.
Sourceimpl HeaderDecode for Expires
impl HeaderDecode for Expires
Sourcefn decode<'i, I>(values: &mut I) -> Result<Expires, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<Expires, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl HeaderEncode for Expires
impl HeaderEncode for Expires
Sourcefn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
fn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
Encode this type to a
HeaderValue, and add it to a container
which has HeaderValue type as each element. Read moreSourcefn encode_to_value(&self) -> Option<HeaderValue>
fn encode_to_value(&self) -> Option<HeaderValue>
Encode this header to
HeaderValue. Read moreSourceimpl Ord for Expires
impl Ord for Expires
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Expires
impl PartialOrd for Expires
impl StructuralPartialEq for Expires
Sourceimpl TypedHeader for Expires
impl TypedHeader for Expires
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.