Origin

Struct Origin 

pub struct Origin(/* private fields */);
The Origin header.

The Origin header is a version of the Referer header that is used for all HTTP fetches and POSTs whose CORS flag is set. This header is often used to inform recipients of the security context of where the request was initiated.

Following the spec, https://fetch.spec.whatwg.org/#origin-header, the value of this header is composed of a String (scheme), Host (host/port)

Examples

use rama_http_headers::Origin;

let origin = Origin::NULL;

Implementations

Source

impl Origin

pub const NULL: Origin

The literal null Origin header.

pub fn is_null(&self) -> bool

Checks if Origin is null.

pub fn scheme(&self) -> &str

Get the “scheme” part of this origin.

pub fn hostname(&self) -> Cow<'_, str>

Get the “hostname” part of this origin.

pub fn port(&self) -> Option<u16>

Get the “port” part of this origin.

pub fn try_from_parts( scheme: &str, host: &str, port: impl Into<Option<u16>>, ) -> Result<Origin, InvalidOrigin>

Tries to build a Origin from three parts, the scheme, the host and an optional port.

pub fn try_from_header_value(value: &HeaderValue) -> Option<Origin>

Try to parse an Origin header value.

Returns None for invalid origins, including values with a path other than /, query, or fragment.