pub struct Referer(/* private fields */);Expand description
Referer header, defined in
RFC7231
The Referer [sic] header field allows the user agent to specify a
URI reference for the resource from which the target URI was obtained
(i.e., the “referrer”, though the field name is misspelled). A user
agent MUST NOT include the fragment and userinfo components of the
URI reference, if any, when generating the Referer field value.
ABNF
Referer = absolute-URI / partial-URIExample values
http://www.example.org/hypertext/Overview.html
Examples
use rama_http_headers::Referer;
let r = Referer::from_static("/People.html#tim");Implementations