Pending

Struct Pending 

pub struct Pending { /* private fields */ }
A pending upgrade, created with pending.

Implementations

Source

impl Pending

pub fn fulfill(self, upgraded: Upgraded)

fulfill the pending upgrade with the given Upgraded stream.

pub fn manual(self)

Don’t fulfill the pending Upgrade, but instead signal that upgrades are handled manually.