pub struct AddAuthorization<S> { /* private fields */ }Expand description
Middleware that adds authorization all requests using the Authorization header.
See the module docs for an example.
You can also use SetRequestHeader if you have a use case that isn’t supported by this
middleware.
Implementations
Sourceimpl<S> AddAuthorization<S>
impl<S> AddAuthorization<S>
Sourcepub fn none(inner: S) -> Self
pub fn none(inner: S) -> Self
Create a new AddAuthorization that does not add any authorization.
Can be useful if you only want to add authorization for some branches of your service.
Sourcepub fn new(inner: S, credential: impl Credentials) -> Self
pub fn new(inner: S, credential: impl Credentials) -> Self
Authorize requests using the given Credentials.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
Sourcepub fn with_sensitive(self, sensitive: bool) -> Self
pub fn with_sensitive(self, sensitive: bool) -> Self
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
Sourcepub fn set_sensitive(&mut self, sensitive: bool) -> &mut Self
pub fn set_sensitive(&mut self, sensitive: bool) -> &mut Self
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
Sourcepub fn with_if_not_present(self, value: bool) -> Self
pub fn with_if_not_present(self, value: bool) -> Self
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.
Sourcepub fn set_if_not_present(&mut self, value: bool) -> &mut Self
pub fn set_if_not_present(&mut self, value: bool) -> &mut Self
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.