pub struct HttpAuthorizer<A, C> { /* private fields */ }Expand description
Utility type to allow you to use any Authorizer
that works with Credentials to authorize the Authorization header,
and return StatusCode::UNAUTHORIZED response with header::WWW_AUTHENTICATE for unauthorized request,
tracing the original error for your convenience.
Implementations
Sourceimpl<A, C> HttpAuthorizer<A, C>
impl<A, C> HttpAuthorizer<A, C>
pub fn new(authorizer: A) -> Self
Sourcepub fn with_allow_anonymous(self, allow: bool) -> Self
pub fn with_allow_anonymous(self, allow: bool) -> Self
Defines whether or not to allow anonymous.
This means that the request is will be authorized automatically,
if no Authorization header was passed in.
Sourcepub fn set_allow_anonymous(&mut self, allow: bool) -> &mut Self
pub fn set_allow_anonymous(&mut self, allow: bool) -> &mut Self
Defines whether or not to allow anonymous.
This means that the request is will be authorized automatically,
if no Authorization header was passed in.