pub struct SizeAbove(/* private fields */);Available on crate feature
compression only.Expand description
Predicate that will only allow compression of responses above a certain size.
Implementations
Sourceimpl SizeAbove
impl SizeAbove
Sourcepub const fn new(min_size_bytes: u64) -> Self
pub const fn new(min_size_bytes: u64) -> Self
Create a new SizeAbove predicate that will only compress responses larger than
min_size_bytes.
The response will be compressed if the exact size cannot be determined through either the
content-length header or StreamingBody::size_hint.