pub struct StreamCompressionLayer<P = DefaultStreamPredicate> { /* private fields */ }compression only.Expand description
Compress response bodies of the underlying service.
This uses the Accept-Encoding header to pick an appropriate encoding and adds the
Content-Encoding header to responses.
See the module docs for more details.
Implementations
Sourceimpl StreamCompressionLayer
impl StreamCompressionLayer
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new StreamCompressionLayer.
Sourcepub fn with_compress_predicate<C>(
self,
predicate: C,
) -> StreamCompressionLayer<C>where
C: Predicate,
pub fn with_compress_predicate<C>(
self,
predicate: C,
) -> StreamCompressionLayer<C>where
C: Predicate,
Replace the current compression predicate.
Sourceimpl<P> StreamCompressionLayer<P>
impl<P> StreamCompressionLayer<P>
Sourcepub fn set_gzip(&mut self, enable: bool) -> &mut Self
pub fn set_gzip(&mut self, enable: bool) -> &mut Self
Sets whether to enable the gzip encoding.
Sourcepub fn with_deflate(self, enable: bool) -> Self
pub fn with_deflate(self, enable: bool) -> Self
Sets whether to enable the Deflate encoding.
Sourcepub fn set_deflate(&mut self, enable: bool) -> &mut Self
pub fn set_deflate(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Deflate encoding.
Sourcepub fn set_br(&mut self, enable: bool) -> &mut Self
pub fn set_br(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Brotli encoding.
Sourcepub fn set_zstd(&mut self, enable: bool) -> &mut Self
pub fn set_zstd(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Zstd encoding.
Sourcepub fn with_quality(self, quality: CompressionLevel) -> Self
pub fn with_quality(self, quality: CompressionLevel) -> Self
Sets the compression quality.
Sourcepub fn set_quality(&mut self, quality: CompressionLevel) -> &mut Self
pub fn set_quality(&mut self, quality: CompressionLevel) -> &mut Self
Sets the compression quality.
Sourcepub fn with_enforce_not_acceptable(self, enable: bool) -> Self
pub fn with_enforce_not_acceptable(self, enable: bool) -> Self
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.
Sourcepub fn set_enforce_not_acceptable(&mut self, enable: bool) -> &mut Self
pub fn set_enforce_not_acceptable(&mut self, enable: bool) -> &mut Self
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.