CompressionLayer

Struct CompressionLayer 

pub struct CompressionLayer<P = DefaultPredicate> { /* private fields */ }
Available on crate feature compression only.
Compress response bodies of the underlying service.

This uses the Accept-Encoding header to pick an appropriate encoding and adds the Content-Encoding header to responses.

See the module docs for more details.

Implementations

Source

impl CompressionLayer

pub fn new() -> Self

Creates a new CompressionLayer.

pub fn with_compress_predicate<C>(self, predicate: C) -> CompressionLayer<C>
where C: Predicate,

Replace the current compression predicate.

Source

impl<P> CompressionLayer<P>

pub fn with_gzip(self, enable: bool) -> Self

Sets whether to enable the gzip encoding.

pub fn set_gzip(&mut self, enable: bool) -> &mut Self

Sets whether to enable the gzip encoding.

pub fn with_deflate(self, enable: bool) -> Self

Sets whether to enable the Deflate encoding.

pub fn set_deflate(&mut self, enable: bool) -> &mut Self

Sets whether to enable the Deflate encoding.

pub fn with_br(self, enable: bool) -> Self

Sets whether to enable the Brotli encoding.

pub fn set_br(&mut self, enable: bool) -> &mut Self

Sets whether to enable the Brotli encoding.

pub fn with_zstd(self, enable: bool) -> Self

Sets whether to enable the Zstd encoding.

pub fn set_zstd(&mut self, enable: bool) -> &mut Self

Sets whether to enable the Zstd encoding.

pub fn with_quality(self, quality: CompressionLevel) -> Self

Sets the compression quality.

pub fn set_quality(&mut self, quality: CompressionLevel) -> &mut Self

Sets the compression quality.

pub fn with_respect_content_encoding_if_possible(self) -> Self

Allow responses with content-encoding.

Useful in case your stack uses that response header as preference. Not something you want for regular servers or proxies however, or most use cases for that matter.

pub fn set_respect_content_encoding_if_possible(&mut self) -> &mut Self

Allow responses with content-encoding.

Useful in case your stack uses that response header as preference. Not something you want for regular servers or proxies however, or most use cases for that matter.

pub fn with_enforce_not_acceptable(self, enable: bool) -> Self

Sets whether to respond with 406 Not Acceptable when the client’s Accept-Encoding header rejects every available representation (e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.

Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.

pub fn set_enforce_not_acceptable(&mut self, enable: bool) -> &mut Self

Sets whether to respond with 406 Not Acceptable when the client’s Accept-Encoding header rejects every available representation (e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.

Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.