#[non_exhaustive]pub enum ConfigError {
InvalidOrigin {
origin: Box<str>,
message: Box<str>,
},
InvalidOriginComponents {
origin: Box<str>,
},
OpaqueOrigin {
origin: Box<str>,
},
}Expand description
Errors that can occur while configuring CsrfLayer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidOrigin
The origin string could not be parsed as a URI.
InvalidOriginComponents
The trusted origin carried a userinfo, path, query, or fragment component; an origin is
scheme://host[:port] only.
OpaqueOrigin
The origin had a scheme other than http/https, or no host, so it can never match a
browser-supplied request Origin.