pub struct DnsResolveModeService<S> { /* private fields */ }Expand description
Service to support configuring the DNS resolve mode.
By default DNS resolving is expected to only be done if it is needed (e.g. because we need to know the IP). Configuring this to be used as eager (when requested) is a way to have requested the intent to reoslve DNS even if it is not needed.
See Dns (rama_core) and DnsResolveMode for more information.
Implementations
Sourceimpl<S> DnsResolveModeService<S>
impl<S> DnsResolveModeService<S>
Sourcepub const fn new(inner: S, header_name: HeaderName) -> Self
pub const fn new(inner: S, header_name: HeaderName) -> Self
Create a new instance of the DnsResolveModeService.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.