GetForwardedHeadersLayer

Struct GetForwardedHeadersLayer 

pub struct GetForwardedHeadersLayer<T = Forwarded> { /* private fields */ }
Layer to extract Forwarded information from the specified T headers.

Use GetForwardedHeaderLayer if you only need a single a header.

This layer can be used to extract the Forwarded information from any specified header T, as long as the header implements the ForwardHeader trait. Multiple headers can be specified as a tuple, and the layer will extract information from them all, and combine the information.

Please take into consideration the following when combining headers:

  • The last header in the tuple will take precedence over the previous headers, if the same information is present in multiple headers.
  • Headers that can contain multiple elements, (e.g. X-Forwarded-For, Via) will combine their elements in the order as specified. That does however mean that in case one header has less elements then the other, that the combination down the line will not be accurate.

Rama also has the following headers already implemented for you to use:

X-Real-Ip, X-Client-Ip, Client-Ip, Cf-Connecting-Ip and True-Client-Ip.

There are no GetForwardedHeadersLayer constructors for these headers, but you can use the GetForwardedHeadersLayer::new constructor and pass the header type as a type parameter in a tuple with other headers.

Implementations

Source

impl<T> GetForwardedHeadersLayer<T>

pub const fn new() -> Self

Create a new GetForwardedHeadersLayer for the specified headers T.