SetForwardedHeadersService

Struct SetForwardedHeadersService 

pub struct SetForwardedHeadersService<S, T = Forwarded> { /* private fields */ }
Middleware Service to write Forwarded information for this proxy, added to the end of the chain of forwarded information already known.

See SetForwardedHeadersLayer for more information.

Implementations

Source

impl<S, T> SetForwardedHeadersService<S, T>

pub fn new(inner: S) -> Self

Create a new SetForwardedHeadersService for the specified headers T.