pub struct Cache {
pub before_request: Option<CacheState>,
pub after_request: Option<CacheState>,
pub comment: Option<ArcStr>,
}Expand description
This objects contains info about a request coming from browser cache.
Fields
before_request: Option<CacheState>State of a cache entry before the request.
Leave out this field if the information is not available.
after_request: Option<CacheState>State of a cache entry after the request.
Leave out this field if the information is not available.
comment: Option<ArcStr>A comment provided by the user or the application.