pub struct CacheState {
pub expires: Timestamp,
pub last_access: Option<ArcStr>,
pub e_tag: Option<ArcStr>,
pub hit_count: Option<i64>,
pub comment: Option<ArcStr>,
}Fields
expires: TimestampDate and time stamp of the request start
(ISO 8601 - YYYY-MM-DDThh:mm:ss.sTZD) Expiration time of the cache entry.
last_access: Option<ArcStr>The last time the cache entry was opened.
e_tag: Option<ArcStr>Etag
hit_count: Option<i64>The number of times the cache entry has been opened.
comment: Option<ArcStr>A comment provided by the user or the application.