Entry

Struct Entry 

pub struct Entry {
    pub page_ref: Option<ArcStr>,
    pub started_date_time: Timestamp,
    pub time: i64,
    pub request: Request,
    pub response: Option<Response>,
    pub cache: Cache,
    pub timings: Timings,
    pub server_ip_address: Option<IpAddr>,
    pub connection: Option<ArcStr>,
    pub comment: Option<ArcStr>,
}
This object represents a single exportred request with its response and metadata.

Fields

page_ref: Option<ArcStr>

Reference to the parent page.

Leave out this field if the application does not support grouping by pages.

started_date_time: Timestamp

Date and time stamp of the request start (ISO 8601 - YYYY-MM-DDThh:mm:ss.sTZD)

time: i64

Total elapsed time of the request in milliseconds.

This is the sum of all timings available in the timings object (i.e. not including -1 values).

request: Request

Detailed info about the request.

response: Option<Response>

Detailed info about the response.

cache: Cache

Info about cache usage.

timings: Timings

Detailed timing info about request/response round trip.

server_ip_address: Option<IpAddr>

IP address of the server that was connected

(result of DNS resolution).

connection: Option<ArcStr>

Unique ID of the parent TCP/IP connection, can be the client or server port number.

Note that a port number doesn’t have to be unique identifier in cases where the port is shared for more connections. If the port isn’t available for the application, any other unique connection ID can be used instead (e.g. connection index).

Leave out this field if the application doesn’t support this info.

comment: Option<ArcStr>

A comment provided by the user or the application.