pub struct Log {
pub version: NonEmptyStr,
pub creator: Creator,
pub browser: Option<Browser>,
pub pages: Option<Vec<Page>>,
pub entries: Vec<Entry>,
pub comment: Option<ArcStr>,
}Expand description
This object represents the root of exported data.
Fields
version: NonEmptyStrVersion number of the format. If empty, string “1.1” is assumed by default.
creator: CreatorName and version info of the log creator application.
browser: Option<Browser>Name and version info of used browser.
pages: Option<Vec<Page>>List of all exported (tracked) pages.
Leave out this field if the application does not support grouping by pages.
entries: Vec<Entry>List of all exported (tracked) requests.
comment: Option<ArcStr>A comment provided by the user or the application.