pub struct Page {
pub started_date_time: Timestamp,
pub id: ArcStr,
pub title: ArcStr,
pub page_timings: PageTimings,
pub comment: Option<ArcStr>,
}Fields
started_date_time: TimestampDate and time stamp of the request start (ISO 8601 - YYYY-MM-DDThh:mm:ss.sTZD)
id: ArcStrUnique identifier of a page within the Log. Entries use it to refer the parent page.
title: ArcStrPage title
page_timings: PageTimingsDetailed timing info about page load.
comment: Option<ArcStr>A comment provided by the user or the application.