pub struct PageTimings {
pub on_content_load: Option<i64>,
pub on_load: Option<i64>,
pub comment: Option<ArcStr>,
}Expand description
This object describes timings for various events (states) fired during the page load.
All times are specified in milliseconds. If a time info is not available appropriate field is set to -1.
Fields
on_content_load: Option<i64>Content of the page loaded.
Number of milliseconds since page load started (page.startedDateTime). Use -1 if the timing does not apply to the current request.
on_load: Option<i64>Page is loaded (onLoad event fired).
Number of milliseconds since page load started (page.startedDateTime). Use -1 if the timing does not apply to the current request.
comment: Option<ArcStr>A comment provided by the user or the application.