pub struct QueryStringPair {
pub name: ArcStr,
pub value: ArcStr,
pub comment: Option<ArcStr>,
}Expand description
This object contains list of all parameters & values parsed from a query string, if any (embedded in Request object).
Fields
name: ArcStrName of parameter.
value: ArcStrValue of parameter.
comment: Option<ArcStr>A comment provided by the user or the application.