pub struct Request {
pub method: ArcStr,
pub url: ArcStr,
pub http_version: HttpVersion,
pub cookies: Vec<Cookie>,
pub headers: Vec<Header>,
pub query_string: Vec<QueryStringPair>,
pub post_data: Option<PostData>,
pub headers_size: i64,
pub body_size: i64,
pub comment: Option<ArcStr>,
}Expand description
This object contains detailed info about performed request.
Fields
method: ArcStrRequest method (GET, POST, …).
url: ArcStrAbsolute URL of the request (fragments are not included).
http_version: HttpVersionRequest HTTP Version.
List of cookie objects.
headers: Vec<Header>List of header objects.
query_string: Vec<QueryStringPair>List of query parameter objects.
post_data: Option<PostData>Posted data info.
headers_size: i64Total number of bytes from the start of the HTTP request message
Until (and including) the double CRLF before the body.
Set to -1 if the info is not available.
body_size: i64Size of the request body (POST data payload) in bytes.
Set to -1 if the info is not available.
comment: Option<ArcStr>A comment provided by the user or the application.
Implementations