Response

Struct Response 

pub struct Response {
    pub status: u16,
    pub status_text: Option<ArcStr>,
    pub http_version: HttpVersion,
    pub cookies: Vec<Cookie>,
    pub headers: Vec<Header>,
    pub content: Content,
    pub redirect_url: Option<ArcStr>,
    pub headers_size: i64,
    pub body_size: i64,
    pub comment: Option<ArcStr>,
}
This object contains detailed info about the response.

Fields

status: u16

Response status.

status_text: Option<ArcStr>

Response status description.

http_version: HttpVersion

Response HTTP Version.

cookies: Vec<Cookie>

List of cookie objects.

headers: Vec<Header>

List of header objects.

content: Content

Details about the response body.

redirect_url: Option<ArcStr>

Redirection target URL from the Location response header.

headers_size: i64

Total number of bytes from the start of the HTTP response message

Until (and including) the double CRLF before the body.

Set to -1 if the info is not available.

body_size: i64

Size of the received response body in bytes.

Set to zero in case of responses coming from the cache (304). Set to -1 if the info is not available.

The size of received response-headers is computed only from headers that are really received from the server. Additional headers appended by the browser are not included in this number, but they appear in the list of header objects.

comment: Option<ArcStr>

A comment provided by the user or the application.

Implementations

Source

impl Response

pub fn from_http_response_parts( parts: &RespParts, payload: &[u8], preserve_sensitive: bool, ) -> Result<Self, BoxError>