pub struct HeaderFromStrConfigService<T, S, C = Vec<T>> { /* private fields */ }Expand description
A Service which extracts a header CSV config from a request or response
and inserts it into the Extensions of that object.
Implementations
Sourceimpl<T, S, C> HeaderFromStrConfigService<T, S, C>
impl<T, S, C> HeaderFromStrConfigService<T, S, C>
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
Sourcepub const fn required(inner: S, header_name: HeaderName) -> Self
pub const fn required(inner: S, header_name: HeaderName) -> Self
Create a new HeaderFromStrConfigService with the given inner service
and header name, on which to extract the config,
and which will fail if the header is missing.
Sourcepub const fn optional(inner: S, header_name: HeaderName) -> Self
pub const fn optional(inner: S, header_name: HeaderName) -> Self
Create a new HeaderFromStrConfigService with the given inner service
and header name, on which to extract the config,
and which will gracefully accept if the header is missing.
Sourcepub fn with_repeat(self, repeat: bool) -> Self
pub fn with_repeat(self, repeat: bool) -> Self
Toggle repeat on/off. When repeat is enabled the
data config will be parsed and inserted as a container of type C (defaults to Vec<T>).
Sourcepub fn set_repeat(&mut self, repeat: bool) -> &mut Self
pub fn set_repeat(&mut self, repeat: bool) -> &mut Self
Toggle repeat on/off. When repeat is enabled the
data config will be parsed and inserted as a container of type C (defaults to Vec<T>).