Module into_response

Module into_response 

Structs

IntoResponseLayer
A Layer that maps Output of an inner service using IntoResponse.
IntoResponseService
A Service that maps Output of an inner service using IntoResponse.