pub struct PropagateHeader<S> { /* private fields */ }Expand description
Middleware that propagates headers from requests to responses.
If the header is present on the request it’ll be applied to the response as well. This could
for example be used to propagate headers such as X-Request-Id.
See the module docs for more details.
Implementations
Sourceimpl<S> PropagateHeader<S>
impl<S> PropagateHeader<S>
Sourcepub const fn new(inner: S, header: HeaderName) -> Self
pub const fn new(inner: S, header: HeaderName) -> Self
Create a new PropagateHeader that propagates the given header.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.