pub struct AddRequiredResponseHeadersLayer { /* private fields */ }Expand description
Layer that applies AddRequiredResponseHeaders which adds a request header.
See AddRequiredResponseHeaders for more details.
Implementations
Sourceimpl AddRequiredResponseHeadersLayer
impl AddRequiredResponseHeadersLayer
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create a new AddRequiredResponseHeadersLayer.
Sourcepub fn with_overwrite(self, overwrite: bool) -> Self
pub fn with_overwrite(self, overwrite: bool) -> Self
Set whether to overwrite the existing headers.
If set to true, the headers will be overwritten.
Default is false.
Sourcepub fn set_overwrite(&mut self, overwrite: bool) -> &mut Self
pub fn set_overwrite(&mut self, overwrite: bool) -> &mut Self
Set whether to overwrite the existing headers.
If set to true, the headers will be overwritten.
Default is false.
Sourcepub fn maybe_with_server_header_value(self, value: Option<HeaderValue>) -> Self
pub fn maybe_with_server_header_value(self, value: Option<HeaderValue>) -> Self
Define the custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn maybe_set_server_header_value(
&mut self,
value: Option<HeaderValue>,
) -> &mut Self
pub fn maybe_set_server_header_value( &mut self, value: Option<HeaderValue>, ) -> &mut Self
Define the custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn with_server_header_value(self, value: HeaderValue) -> Self
pub fn with_server_header_value(self, value: HeaderValue) -> Self
Define the custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn set_server_header_value(&mut self, value: HeaderValue) -> &mut Self
pub fn set_server_header_value(&mut self, value: HeaderValue) -> &mut Self
Define the custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn without_server_header_value(self) -> Self
pub fn without_server_header_value(self) -> Self
Define the custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn unset_server_header_value(&mut self) -> &mut Self
pub fn unset_server_header_value(&mut self) -> &mut Self
Define the custom SERVER header value.
By default a versioned rama value is used.