pub struct SetResponseHeader<S, M> { /* private fields */ }Expand description
Middleware that sets a header on the response.
Implementations
Sourceimpl<S, H: HeaderEncode> SetResponseHeader<S, TypedHeaderAsMaker<H>>
impl<S, H: HeaderEncode> SetResponseHeader<S, TypedHeaderAsMaker<H>>
Sourcepub fn overriding_typed(inner: S, header: H) -> Self
pub fn overriding_typed(inner: S, header: H) -> Self
Create a new SetResponseHeader from a typed HeaderEncode.
See SetResponseHeader::overriding for more details.
Sourcepub fn appending_typed(inner: S, header: H) -> Self
pub fn appending_typed(inner: S, header: H) -> Self
Create a new SetResponseHeader from a typed HeaderEncode.
See SetResponseHeader::appending for more details.
Sourcepub fn if_not_present_typed(inner: S, header: H) -> Self
pub fn if_not_present_typed(inner: S, header: H) -> Self
Create a new SetResponseHeader from a typed HeaderEncode.
See SetResponseHeader::if_not_present for more details.
Sourceimpl<S, M> SetResponseHeader<S, M>
impl<S, M> SetResponseHeader<S, M>
Sourcepub fn overriding(inner: S, header_name: HeaderName, make: M) -> Self
pub fn overriding(inner: S, header_name: HeaderName, make: M) -> Self
Create a new SetResponseHeader.
If a previous value exists for the same header, it is removed and replaced with the new header value.
Sourcepub fn appending(inner: S, header_name: HeaderName, make: M) -> Self
pub fn appending(inner: S, header_name: HeaderName, make: M) -> Self
Create a new SetResponseHeader.
The new header is always added, preserving any existing values. If previous values exist, the header will have multiple values.
Sourcepub fn if_not_present(inner: S, header_name: HeaderName, make: M) -> Self
pub fn if_not_present(inner: S, header_name: HeaderName, make: M) -> Self
Create a new SetResponseHeader.
If a previous value exists for the header, the new value is not inserted.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
Sourceimpl<S, F, A> SetResponseHeader<S, BoxMakeHeaderValueFactoryFn<F, A>>
impl<S, F, A> SetResponseHeader<S, BoxMakeHeaderValueFactoryFn<F, A>>
Sourcepub fn overriding_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
pub fn overriding_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
Create a new SetResponseHeader from a header::MakeHeaderValueFn.
See SetResponseHeader::overriding for more details.
Sourcepub fn appending_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
pub fn appending_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
Create a new SetResponseHeader from a header::MakeHeaderValueFn.
See SetResponseHeader::appending for more details.
Sourcepub fn if_not_present_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
pub fn if_not_present_fn(inner: S, header_name: HeaderName, make_fn: F) -> Self
Create a new SetResponseHeader from a header::MakeHeaderValueFn.
See SetResponseHeader::if_not_present for more details.
Sourceimpl<S, M> SetResponseHeader<S, M>
impl<S, M> SetResponseHeader<S, M>
Sourcepub fn overriding_default(
inner: S,
header_name: HeaderName,
) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
pub fn overriding_default( inner: S, header_name: HeaderName, ) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
Create a new SetResponseHeader from a Default MakeHeaderValue.
See SetResponseHeader::overriding for more details.
Sourcepub fn appending_default(
inner: S,
header_name: HeaderName,
) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
pub fn appending_default( inner: S, header_name: HeaderName, ) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
Create a new SetResponseHeader from a Default MakeHeaderValue.
See SetResponseHeader::appending for more details.
Sourcepub fn if_not_present_default(
inner: S,
header_name: HeaderName,
) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
pub fn if_not_present_default( inner: S, header_name: HeaderName, ) -> SetResponseHeader<S, MakeHeaderValueDefault<M>>
Create a new SetResponseHeader from a Default MakeHeaderValue.
See SetResponseHeader::if_not_present for more details.
Sourceimpl<S, M: TypedHeader> SetResponseHeader<S, M>
impl<S, M: TypedHeader> SetResponseHeader<S, M>
Sourcepub fn overriding_default_typed(
inner: S,
) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
pub fn overriding_default_typed( inner: S, ) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
Create a new SetResponseHeader from a Default TypedHeader.
See SetResponseHeader::overriding for more details.
Sourcepub fn appending_default_typed(
inner: S,
) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
pub fn appending_default_typed( inner: S, ) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
Create a new SetResponseHeader from a Default TypedHeader.
See SetResponseHeader::appending for more details.
Sourcepub fn if_not_present_default_typed(
inner: S,
) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
pub fn if_not_present_default_typed( inner: S, ) -> SetResponseHeader<S, MakeHeaderValueDefault<TypedHeaderAsMaker<M>>>
Create a new SetResponseHeader from a Default TypedHeader.
See SetResponseHeader::if_not_present for more details.