TimeoutBody

Struct TimeoutBody 

pub struct TimeoutBody<B> { /* private fields */ }
Middleware that applies a timeout to request and response bodies.

Wrapper around a [Body][http_body::Body] to time out if data is not ready within the specified duration. The timeout is enforced between consecutive [Frame][http_body::Frame] polls, and it resets after each poll. The total time to produce a [Body][http_body::Body] could exceed the timeout duration without timing out, as long as no single interval between polls exceeds the timeout.

If the [Body][http_body::Body] does not produce a requested data frame within the timeout period, it will return a TimeoutError.

Differences from [Timeout][crate::timeout::Timeout]

[Timeout][crate::timeout::Timeout] applies a timeout to the request future, not body. That timeout is not reset when bytes are handled, whether the request is active or not. Bodies are handled asynchronously outside of the tower stack’s future and thus needs an additional timeout.

Example

use rama_core::bytes::Bytes;
use std::time::Duration;
use rama_http::{Request, Response};
use rama_http::body::util::Full;
use rama_http::layer::timeout::RequestBodyTimeoutLayer;
use rama_core::{Layer, service::service_fn};

async fn handle(_: Request<Full<Bytes>>) -> Result<Response<Full<Bytes>>, std::convert::Infallible> {
    // ...
}

let svc = RequestBodyTimeoutLayer::new(
    // Timeout bodies after 30 seconds of inactivity
    Duration::from_secs(30)
).layer(service_fn(handle));

Implementations

Source

impl<B> TimeoutBody<B>

pub fn new(timeout: Duration, body: B) -> Self

Creates a new TimeoutBody.