pub struct RequestWriterLayer<W> { /* private fields */ }Expand description
Middleware to print Http request in std format.
See the module docs for more details.
Implementations
Sourceimpl<W> RequestWriterLayer<W>
impl<W> RequestWriterLayer<W>
Sourcepub const fn new(writer: W) -> Self
pub const fn new(writer: W) -> Self
Create a new RequestWriterLayer with a custom RequestWriter.
Sourceimpl RequestWriterLayer<UnboundedSender<Request>>
impl RequestWriterLayer<UnboundedSender<Request>>
Sourcepub fn writer_unbounded<W>(
executor: &Executor,
writer: W,
mode: Option<WriterMode>,
) -> Self
pub fn writer_unbounded<W>( executor: &Executor, writer: W, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterLayer that prints requests to an AsyncWriter
over an unbounded channel
Sourcepub fn stdout_unbounded(executor: &Executor, mode: Option<WriterMode>) -> Self
pub fn stdout_unbounded(executor: &Executor, mode: Option<WriterMode>) -> Self
Create a new RequestWriterService that prints requests to stdout
over an unbounded channel.
Sourcepub fn stderr_unbounded(executor: &Executor, mode: Option<WriterMode>) -> Self
pub fn stderr_unbounded(executor: &Executor, mode: Option<WriterMode>) -> Self
Create a new RequestWriterService that prints requests to stderr
over an unbounded channel.
Sourceimpl RequestWriterLayer<Sender<Request>>
impl RequestWriterLayer<Sender<Request>>
Sourcepub fn writer<W>(
executor: &Executor,
writer: W,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn writer<W>( executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterLayer that prints requests to an AsyncWriter
over a bounded channel with a fixed buffer size.
Sourcepub fn stdout(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn stdout( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stdout
over a bounded channel with a fixed buffer size.
Sourcepub fn stderr(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn stderr( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stderr
over a bounded channel with a fixed buffer size.