pub struct RequestWriterService<S, W> { /* private fields */ }Expand description
Middleware to print Http request in std format.
See the module docs for more details.
Implementations
Sourceimpl<S, W> RequestWriterService<S, W>
impl<S, W> RequestWriterService<S, W>
Sourcepub const fn new(inner: S, writer: W) -> Self
pub const fn new(inner: S, writer: W) -> Self
Create a new RequestWriterService with a custom RequestWriter.
Sourceimpl<S> RequestWriterService<S, UnboundedSender<Request>>
impl<S> RequestWriterService<S, UnboundedSender<Request>>
Sourcepub fn writer_unbounded<W>(
inner: S,
executor: &Executor,
writer: W,
mode: Option<WriterMode>,
) -> Self
pub fn writer_unbounded<W>( inner: S, executor: &Executor, writer: W, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to an AsyncWriter
over an unbounded channel
Sourcepub fn stdout_unbounded(
inner: S,
executor: &Executor,
mode: Option<WriterMode>,
) -> Self
pub fn stdout_unbounded( inner: S, executor: &Executor, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stdout
over an unbounded channel.
Sourcepub fn stderr_unbounded(
inner: S,
executor: &Executor,
mode: Option<WriterMode>,
) -> Self
pub fn stderr_unbounded( inner: S, executor: &Executor, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stderr
over an unbounded channel.
Sourceimpl<S> RequestWriterService<S, Sender<Request>>
impl<S> RequestWriterService<S, Sender<Request>>
Sourcepub fn writer<W>(
inner: S,
executor: &Executor,
writer: W,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn writer<W>( inner: S, executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to an AsyncWriter
over a bounded channel with a fixed buffer size.
Sourcepub fn stdout(
inner: S,
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn stdout( inner: S, executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stdout
over a bounded channel with a fixed buffer size.
Sourcepub fn stderr(
inner: S,
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> Self
pub fn stderr( inner: S, executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> Self
Create a new RequestWriterService that prints requests to stderr
over a bounded channel with a fixed buffer size.