Module upgrade

Module upgrade 

middleware to handle branching into http upgrade services

See UpgradeService for more details.

Re-exports

pub use crate::io::upgrade::Upgraded;

Modules

mitm
service
upgrade service to handle branching into http upgrade services

Structs

DefaultHttpProxyConnectReplyService
A default Service which responds on an http (proxy) connect with a default http response.
HttpProxyConnectRelayServiceRequestMatcher
Default matcher that can be used for Http proxy connects.
HttpProxyConnectRelayServiceResponseMatcher
Created by HttpProxyConnectRelayServiceRequestMatcher for a valid http proxy connect request match, this response matcher half ensures the returned status code is successfull.
UpgradeLayer
UpgradeLayer is a middleware that can be used to upgrade a request.
UpgradeResponse
UpgradeService
Upgrade service can be used to handle the possibility of upgrading a request, after which it will pass down the transport RW to the attached upgrade service.