DefaultHttpProxyConnectReplyService

Struct DefaultHttpProxyConnectReplyService 

#[non_exhaustive]
pub struct DefaultHttpProxyConnectReplyService;
A default Service which responds on an http (proxy) connect with a default http response.

It can also be used for other HTTP connect purposes, but that is not what the service is intended for.

Implementations