pub struct UpgradeService<S, O> { /* private fields */ }Expand description
Upgrade service can be used to handle the possibility of upgrading a request, after which it will pass down the transport RW to the attached upgrade service.
Implementations
Sourceimpl<S, O> UpgradeService<S, O>
impl<S, O> UpgradeService<S, O>
Sourcepub fn new(
handlers: Vec<Arc<UpgradeHandler<O>>>,
inner: S,
exec: Executor,
error_sink: Arc<dyn ErrorSink>,
) -> Self
pub fn new( handlers: Vec<Arc<UpgradeHandler<O>>>, inner: S, exec: Executor, error_sink: Arc<dyn ErrorSink>, ) -> Self
Create a new UpgradeService.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.