pub struct RequestVersionAdapter<S> { /* private fields */ }Expand description
ConnectorService which will adapt the request version if needed.
It will adapt the request version to TargetHttpVersion, or the configured
default version
Implementations
Sourceimpl<S> RequestVersionAdapter<S>
impl<S> RequestVersionAdapter<S>
pub fn new(inner: S) -> Self
Sourcepub fn maybe_with_default_version(self, version: Option<Version>) -> Self
pub fn maybe_with_default_version(self, version: Option<Version>) -> Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
Sourcepub fn maybe_set_default_version(
&mut self,
version: Option<Version>,
) -> &mut Self
pub fn maybe_set_default_version( &mut self, version: Option<Version>, ) -> &mut Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
Sourcepub fn with_default_version(self, version: Version) -> Self
pub fn with_default_version(self, version: Version) -> Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
Sourcepub fn set_default_version(&mut self, version: Version) -> &mut Self
pub fn set_default_version(&mut self, version: Version) -> &mut Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
Sourcepub fn without_default_version(self) -> Self
pub fn without_default_version(self) -> Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
Sourcepub fn unset_default_version(&mut self) -> &mut Self
pub fn unset_default_version(&mut self) -> &mut Self
Set default request Version which will be used if TargetHttpVersion is
is not present in extensions