RequestVersionAdapterLayer

Struct RequestVersionAdapterLayer 

pub struct RequestVersionAdapterLayer { /* private fields */ }
ConnectorService layer which will adapt the request version if needed.

It will adapt the request version to TargetHttpVersion, or the configured default version

Implementations

Source

impl RequestVersionAdapterLayer

pub fn new() -> Self

pub fn maybe_with_default_version(self, version: Option<Version>) -> Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions

pub fn maybe_set_default_version( &mut self, version: Option<Version>, ) -> &mut Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions

pub fn with_default_version(self, version: Version) -> Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions

pub fn set_default_version(&mut self, version: Version) -> &mut Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions

pub fn without_default_version(self) -> Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions

pub fn unset_default_version(&mut self) -> &mut Self

Set default request Version which will be used if TargetHttpVersion is is not present in extensions