pub struct HeaderByteLength(pub usize);Expand description
Byte length of the raw bytes of the request/response headers (excl. trailers).
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for HeaderByteLength
impl Clone for HeaderByteLength
Sourcefn clone(&self) -> HeaderByteLength
fn clone(&self) -> HeaderByteLength
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for HeaderByteLength
Sourceimpl Debug for HeaderByteLength
impl Debug for HeaderByteLength
impl Eq for HeaderByteLength
impl Extension for HeaderByteLength
impl HttpExtension for HeaderByteLength
Sourceimpl Ord for HeaderByteLength
impl Ord for HeaderByteLength
Sourcefn cmp(&self, other: &HeaderByteLength) -> Ordering
fn cmp(&self, other: &HeaderByteLength) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HeaderByteLength
impl PartialEq for HeaderByteLength
Sourcefn eq(&self, other: &HeaderByteLength) -> bool
fn eq(&self, other: &HeaderByteLength) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HeaderByteLength
impl PartialOrd for HeaderByteLength
impl StructuralPartialEq for HeaderByteLength