a!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Together with its href attribute, creates a hyperlink to web pages, files, email addresses, locations within the current page, or anything else a URL can address.