address!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Indicates that the enclosed HTML provides contact information for a person or people, or for an organization.
address!() { /* proc-macro */ }html only.Indicates that the enclosed HTML provides contact information for a person or people, or for an organization.