base!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Specifies the base URL to use for all relative URLs in a document. There can be only one such element in a document.
base!() { /* proc-macro */ }html only.Specifies the base URL to use for all relative URLs in a document. There can be only one such element in a document.