bdi

Macro bdi 

bdi!() { /* proc-macro */ }
Available on crate feature html only.
Tells the browser’s bidirectional algorithm to treat the text it contains in isolation from its surrounding text. It’s particularly useful when a website dynamically inserts some text and doesn’t know the directionality of the text being inserted.