bdo!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Overrides the current directionality of text, so that the text within is rendered in a different direction.
bdo!() { /* proc-macro */ }html only.Overrides the current directionality of text, so that the text within is rendered in a different direction.