body!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents the content of an HTML document. There can be only one such element in a document.
body!() { /* proc-macro */ }html only.Represents the content of an HTML document. There can be only one such element in a document.