br

Macro br 

br!() { /* proc-macro */ }
Available on crate feature html only.
Produces a line break in text (carriage-return). It is useful for writing a poem or an address, where the division of lines is significant.