details

Macro details 

details!() { /* proc-macro */ }
Available on crate feature html only.
Creates a disclosure widget in which information is visible only when the widget is toggled into an “open” state. A summary or label must be provided using the summary! element.