dialog!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.
dialog!() { /* proc-macro */ }html only.Represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.