embed!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.