head!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Contains machine-readable information (metadata) about the document, like its title, scripts, and style sheets.
head!() { /* proc-macro */ }html only.Contains machine-readable information (metadata) about the document, like its title, scripts, and style sheets.