hgroup!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a heading grouped with any secondary content, such as subheadings, an alternative title, or a tagline.
hgroup!() { /* proc-macro */ }html only.Represents a heading grouped with any secondary content, such as subheadings, an alternative title, or a tagline.