hr!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a thematic break between paragraph-level elements: for example, a change of scene in a story, or a shift of topic within a section.
hr!() { /* proc-macro */ }html only.Represents a thematic break between paragraph-level elements: for example, a change of scene in a story, or a shift of topic within a section.