html!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents the root (top-level element) of an HTML document, so it is also referred to as the root element. All other elements must be descendants of this element.