ins

Macro ins 

ins!() { /* proc-macro */ }
Available on crate feature html only.
Represents a range of text that has been added to a document. You can use the del! element to similarly represent a range of text that has been deleted from the document.