object!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a plugin.
object!() { /* proc-macro */ }html only.Represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a plugin.