output!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Container element into which a site or app can inject the results of a calculation or the outcome of a user action.
output!() { /* proc-macro */ }html only.Container element into which a site or app can inject the results of a calculation or the outcome of a user action.