textarea!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a multi-line plain-text editing control, useful when you want to allow users to enter a sizeable amount of free-form text, for example, a comment on a review or feedback form.