time!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a specific period in time. It may include the datetime attribute to translate dates into machine-readable format, allowing for better search engine results or custom features such as reminders.