var

Macro var 

var!() { /* proc-macro */ }
Available on crate feature html only.
Represents the name of a variable in a mathematical expression or a programming context. It’s typically presented using an italicized version of the current typeface, although that behavior is browser-dependent.