pub struct Selector { /* private fields */ }Available on crate feature
html only.Expand description
A parsed CSS selector string.
A selector string may contain a comma-separated list of complex
selectors (e.g. "a, .b > c"); the Selector matches an element if
any of those complex selectors matches it.
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn tag(name: impl AsRef<str>) -> Self
pub fn tag(name: impl AsRef<str>) -> Self
A type (tag) selector, e.g. div. Shorthand for
Selector::of(Compound::tag(name)).
Sourcepub fn child(self, compound: Compound) -> Self
pub fn child(self, compound: Compound) -> Self
Extends the current complex selector with a child combinator:
self > compound.
Sourcepub fn descendant(self, compound: Compound) -> Self
pub fn descendant(self, compound: Compound) -> Self
Extends the current complex selector with a descendant combinator:
self compound.