tokenize

Function tokenize 

pub fn tokenize<S: TokenSink>(
    input: &[u8],
    sink: &mut S,
) -> Result<(), ParsingAmbiguityError>
Available on crate feature html only.
Tokenizes input in one pass with the default (non-strict) tokenizer, dispatching events to sink.

Errors

The default tokenizer is non-strict, so this does not abort on ambiguous contexts; build a strict Tokenizer (via with_strict) to get a ParsingAmbiguityError.