AtomFeedBuilder

Struct AtomFeedBuilder 

pub struct AtomFeedBuilder<I, T, U> { /* private fields */ }
Available on crate feature rss only.
Type-state builder for AtomFeed.

I, T, and U track whether id, title, and updated have been provided. build is only available once all three are Present.

Implementations

Source

impl<T, U> AtomFeedBuilder<Missing, T, U>

pub fn id(self, id: Uri) -> AtomFeedBuilder<Present, T, U>

Source

impl<I, U> AtomFeedBuilder<I, Missing, U>

pub fn title(self, title: impl Into<AtomText>) -> AtomFeedBuilder<I, Present, U>

Source

impl<I, T> AtomFeedBuilder<I, T, Missing>

pub fn updated(self, ts: Timestamp) -> AtomFeedBuilder<I, T, Present>

Source

impl<I, T, U> AtomFeedBuilder<I, T, U>

pub fn with_author(self, author: AtomPerson) -> Self

Append a feed-level author. Call multiple times to add more.

pub fn set_author(&mut self, author: AtomPerson) -> &mut Self

Append a feed-level author. Call multiple times to add more.

Append a feed-level <link>. Call multiple times to add more.

Append a feed-level <link>. Call multiple times to add more.

pub fn with_category(self, cat: AtomCategory) -> Self

Append a feed-level category. Call multiple times to add more.

pub fn set_category(&mut self, cat: AtomCategory) -> &mut Self

Append a feed-level category. Call multiple times to add more.

pub fn with_contributor(self, c: AtomPerson) -> Self

Append a feed-level contributor. Call multiple times to add more.

pub fn set_contributor(&mut self, c: AtomPerson) -> &mut Self

Append a feed-level contributor. Call multiple times to add more.

pub fn with_generator(self, generator: AtomGenerator) -> Self

pub fn set_generator(&mut self, generator: AtomGenerator) -> &mut Self

pub fn with_icon(self, icon: Uri) -> Self

pub fn set_icon(&mut self, icon: Uri) -> &mut Self

pub fn with_rights(self, rights: impl Into<AtomText>) -> Self

pub fn set_rights(&mut self, rights: impl Into<AtomText>) -> &mut Self

pub fn with_subtitle(self, subtitle: impl Into<AtomText>) -> Self

pub fn set_subtitle(&mut self, subtitle: impl Into<AtomText>) -> &mut Self

pub fn with_entry(self, entry: AtomEntry) -> Self

Append a single entry. Call multiple times to attach more.

pub fn set_entry(&mut self, entry: AtomEntry) -> &mut Self

Append a single entry. Call multiple times to attach more.

pub fn with_entries(self, entries: impl IntoIterator<Item = AtomEntry>) -> Self

pub fn set_entries( &mut self, entries: impl IntoIterator<Item = AtomEntry>, ) -> &mut Self

pub fn with_feed_extensions(self, ext: FeedExtensions) -> Self

pub fn set_feed_extensions(&mut self, ext: FeedExtensions) -> &mut Self

Source

impl AtomFeedBuilder<Present, Present, Present>

pub fn build(self) -> AtomFeed