pub struct RequestBuilder<'a, S, Response> { /* private fields */ }Expand description
A builder to construct the properties of a Request.
Constructed using HttpClientExt.
Implementations
Sourceimpl<S, Body> RequestBuilder<'_, S, Response<Body>>
impl<S, Body> RequestBuilder<'_, S, Response<Body>>
Sourcepub fn header<K, V>(self, key: K, value: V) -> Selfwhere
K: IntoHeaderName,
V: IntoHeaderValue,
pub fn header<K, V>(self, key: K, value: V) -> Selfwhere
K: IntoHeaderName,
V: IntoHeaderValue,
Add a Header to this Request.
Sourcepub fn typed_header<H>(self, header: H) -> Selfwhere
H: HeaderEncode,
pub fn typed_header<H>(self, header: H) -> Selfwhere
H: HeaderEncode,
Add a typed HeaderEncode to this Request.
Sourcepub fn overwrite_header<K, V>(self, key: K, value: V) -> Selfwhere
K: IntoHeaderName,
V: IntoHeaderValue,
pub fn overwrite_header<K, V>(self, key: K, value: V) -> Selfwhere
K: IntoHeaderName,
V: IntoHeaderValue,
Overwrite a Header to this Request.
Sourcepub fn overwrite_typed_header<H>(self, header: H) -> Selfwhere
H: HeaderEncode,
pub fn overwrite_typed_header<H>(self, header: H) -> Selfwhere
H: HeaderEncode,
Overwrite a typed HeaderEncode to this Request.
Sourcepub fn auth(self, credentials: impl Credentials) -> Self
pub fn auth(self, credentials: impl Credentials) -> Self
Enable HTTP authentication.
Sourcepub fn extension<T>(self, extension: T) -> Selfwhere
T: Extension,
pub fn extension<T>(self, extension: T) -> Selfwhere
T: Extension,
Adds an extension to this builder
Sourcepub fn extensions(&self) -> Option<&Extensions>
pub fn extensions(&self) -> Option<&Extensions>
Get access to the underlying Extensions
This function will return None if Extensions are not available,
or if this builder is in an error state
Sourcepub fn multipart(self, form: Form) -> Self
Available on crate feature multipart only.
pub fn multipart(self, form: Form) -> Self
multipart only.Set a multipart::Form as the body of this
Request.
Sets the Content-Type header to
multipart/form-data; boundary={boundary} and, when every part has a
known size, the Content-Length header. An existing Content-Type
header is overwritten.
Sourcepub fn octet_stream<T: Into<Bytes>>(self, bytes: T) -> Self
pub fn octet_stream<T: Into<Bytes>>(self, bytes: T) -> Self
Sourcepub async fn try_into_request(self) -> Result<Request, BoxError>
pub async fn try_into_request(self) -> Result<Request, BoxError>