pub struct DatastarScript(/* private fields */);Expand description
Datastar script ready to be served.
Embedded version of a recent enough datastar frontend script compatible with the datastar support embedded in rama.
Source: https://cdn.jsdelivr.net/gh/starfederation/datastar@1.0.2/bundles/datastar.js
Learn more about datastar at https://data-star.dev/ or in the book: https://ramaproxy.org/book/web_servers.html#datastar.
Implementations
Sourceimpl DatastarScript
impl DatastarScript
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DatastarScript ready to be served.