WebService

Struct WebService 

pub struct WebService<State = ()> { /* private fields */ }
A basic web service that can be used to serve HTTP requests.

Note that this service boxes all the internal services, so it is not as efficient as it could be. For those locations where you need do not desire the convenience over performance, you can instead use a tuple of (M, S) tuples, where M is a matcher and S is a service, e.g. ((MethodMatcher::GET, service_a), (MethodMatcher::POST, service_b), service_fallback).

Implementations

Source

impl WebService

pub fn new() -> Self

create a new web service

Source

impl<State> WebService<State>
where State: Send + Sync + Clone + 'static,

pub fn new_with_state(state: State) -> Self

pub fn with_get<I, T>(self, path: &str, service: I) -> Self

add a GET route to the web service, using the given service.

pub fn set_get<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a GET route to the web service, using the given service.

pub fn with_post<I, T>(self, path: &str, service: I) -> Self

add a POST route to the web service, using the given service.

pub fn set_post<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a POST route to the web service, using the given service.

pub fn with_put<I, T>(self, path: &str, service: I) -> Self

add a PUT route to the web service, using the given service.

pub fn set_put<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a PUT route to the web service, using the given service.

pub fn with_delete<I, T>(self, path: &str, service: I) -> Self

add a DELETE route to the web service, using the given service.

pub fn set_delete<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a DELETE route to the web service, using the given service.

pub fn with_patch<I, T>(self, path: &str, service: I) -> Self

add a PATCH route to the web service, using the given service.

pub fn set_patch<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a PATCH route to the web service, using the given service.

pub fn with_head<I, T>(self, path: &str, service: I) -> Self

add a HEAD route to the web service, using the given service.

pub fn set_head<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a HEAD route to the web service, using the given service.

pub fn with_options<I, T>(self, path: &str, service: I) -> Self

add a OPTIONS route to the web service, using the given service.

pub fn set_options<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a OPTIONS route to the web service, using the given service.

pub fn with_trace<I, T>(self, path: &str, service: I) -> Self

add a TRACE route to the web service, using the given service.

pub fn set_trace<I, T>(&mut self, path: &str, service: I) -> &mut Self

add a TRACE route to the web service, using the given service.

pub fn with_nest_make_fn( self, prefix: &str, configure_svc: impl FnOnce(Self) -> Self, ) -> Self

Nest a web service under the given path.

The nested service will receive a request with the path prefix removed.

Note: this sub-webservice is configured with the same State this router has.

pub fn set_nest_make_fn( &mut self, prefix: &str, configure_svc: impl FnOnce(Self) -> Self, ) -> &mut Self

Nest a web service under the given path.

The nested service will receive a request with the path prefix removed.

Note: this sub-webservice is configured with the same State this router has.

pub fn with_nest_service<I, T>( self, prefix: impl AsRef<str>, service: I, ) -> Self
where I: IntoEndpointService<T>, I::Service: Service<Request, Output = Response, Error = Infallible>,

Nest a web service under the given path.

The nested service will receive a request with the path prefix removed.

Warning: This sub-service has no notion of the state this webservice has. If you want to create a nested-service that shares the same state this webservice has, use WebService::set_nest_make_fn instead.

pub fn set_nest_service<I, T>( &mut self, prefix: impl AsRef<str>, service: I, ) -> &mut Self
where I: IntoEndpointService<T>, I::Service: Service<Request, Output = Response, Error = Infallible>,

Nest a web service under the given path.

The nested service will receive a request with the path prefix removed.

Warning: This sub-service has no notion of the state this webservice has. If you want to create a nested-service that shares the same state this webservice has, use WebService::set_nest_make_fn instead.

pub fn with_file(self, prefix: &str, path: impl AsRef<Path>, mime: Mime) -> Self

serve the given file under the given path.

pub fn set_file( &mut self, prefix: &str, path: impl AsRef<Path>, mime: Mime, ) -> &mut Self

serve the given file under the given path.

pub fn with_dir(self, prefix: &str, path: impl AsRef<Path>) -> Self

serve the given directory under the given path.

pub fn set_dir(&mut self, prefix: &str, path: impl AsRef<Path>) -> &mut Self

serve the given directory under the given path.

pub fn with_dir_with_serve_mode( self, prefix: &str, path: impl AsRef<Path>, mode: DirectoryServeMode, ) -> Self

serve the given directory under the given path, with a custom serve move.

pub fn set_dir_with_serve_mode( &mut self, prefix: &str, path: impl AsRef<Path>, mode: DirectoryServeMode, ) -> &mut Self

serve the given directory under the given path, with a custom serve move.

pub fn with_dir_embed(self, prefix: &str, dir: Dir<'static>) -> Self

serve the given embedded directory under the given path.

pub fn set_dir_embed(&mut self, prefix: &str, dir: Dir<'static>) -> &mut Self

serve the given embedded directory under the given path.

pub fn with_dir_embed_with_serve_mode( self, prefix: &str, dir: Dir<'static>, mode: DirectoryServeMode, ) -> Self

serve the given embedded directory under the given path with a custom serve move.

pub fn set_dir_embed_with_serve_mode( &mut self, prefix: &str, dir: Dir<'static>, mode: DirectoryServeMode, ) -> &mut Self

serve the given embedded directory under the given path with a custom serve move.

pub fn with_matcher<I, T>(self, matcher: HttpMatcher<Body>, service: I) -> Self

add a route to the web service which matches the given matcher, using the given service.

pub fn set_matcher<I, T>( &mut self, matcher: HttpMatcher<Body>, service: I, ) -> &mut Self

add a route to the web service which matches the given matcher, using the given service.

pub fn with_not_found<I, T>(self, service: I) -> Self

use the given service in case no match could be found.

pub fn set_not_found<I, T>(&mut self, service: I) -> &mut Self

use the given service in case no match could be found.