pub struct ExecuteScript {
pub script: NonEmptyStr,
pub auto_remove: Option<bool>,
pub attributes: Option<Vec<ScriptAttribute>>,
}Expand description
ExecuteScript executes JavaScript in the browser
See the Datastar documentation.
Fields
script: NonEmptyStrscript is a string that represents the JavaScript to be executed by the browser.
auto_remove: Option<bool>Whether to remove the script after execution.
If not provided the Datastar client side will default to true.
attributes: Option<Vec<ScriptAttribute>>A list of attributes to add to the script element.
If not provided the Datastar client side will default to type module.
Each item in the array must be a string in the format key value,
boolean value used in cased of boolean attributes.
Implementations
Sourceimpl ExecuteScript
impl ExecuteScript
pub const TYPE: EventType = EventType::PatchElements
Sourcepub const fn new(script: NonEmptyStr) -> ExecuteScript
pub const fn new(script: NonEmptyStr) -> ExecuteScript
Create a new ExecuteScript data blob.
Sourcepub fn try_into_sse_event(self) -> Result<Event<ExecuteScript>, EventBuildError>
pub fn try_into_sse_event(self) -> Result<Event<ExecuteScript>, EventBuildError>
Consume self as an Event.
Sourcepub fn try_into_datastar_event<T>(
self,
) -> Result<Event<EventData<T>>, EventBuildError>
pub fn try_into_datastar_event<T>( self, ) -> Result<Event<EventData<T>>, EventBuildError>
Consume self as a super::DatastarEvent.
Sourcepub fn with_auto_remove(self, auto_remove: bool) -> ExecuteScript
pub fn with_auto_remove(self, auto_remove: bool) -> ExecuteScript
Set whether to remove the script after execution.
Sourcepub fn set_auto_remove(&mut self, auto_remove: bool) -> &mut ExecuteScript
pub fn set_auto_remove(&mut self, auto_remove: bool) -> &mut ExecuteScript
Set whether to remove the script after execution.
Sourcepub fn with_attribute(self, attribute: ScriptAttribute) -> ExecuteScript
pub fn with_attribute(self, attribute: ScriptAttribute) -> ExecuteScript
Set a single attribute to add to the script element.
This overwrites any previously added script attribute.
Sourcepub fn set_attribute(
&mut self,
attribute: ScriptAttribute,
) -> &mut ExecuteScript
pub fn set_attribute( &mut self, attribute: ScriptAttribute, ) -> &mut ExecuteScript
Set a single attribute to add to the script element.
This overwrites any previously added script attribute.
Sourcepub fn with_attributes(
self,
attributes: impl IntoIterator<Item = ScriptAttribute>,
) -> ExecuteScript
pub fn with_attributes( self, attributes: impl IntoIterator<Item = ScriptAttribute>, ) -> ExecuteScript
Set a list of attributes to add to the script element.
Sourcepub fn set_attributes(
&mut self,
attributes: impl IntoIterator<Item = ScriptAttribute>,
) -> &mut ExecuteScript
pub fn set_attributes( &mut self, attributes: impl IntoIterator<Item = ScriptAttribute>, ) -> &mut ExecuteScript
Set a list of attributes to add to the script element.
Sourcepub fn with_additional_attribute(
self,
attribute: ScriptAttribute,
) -> ExecuteScript
pub fn with_additional_attribute( self, attribute: ScriptAttribute, ) -> ExecuteScript
Add an additional attribute
Sourcepub fn set_additional_attribute(
&mut self,
attribute: ScriptAttribute,
) -> &mut ExecuteScript
pub fn set_additional_attribute( &mut self, attribute: ScriptAttribute, ) -> &mut ExecuteScript
Add an additional attribute
Sourcepub fn with_additional_attributes(
self,
attributes: impl IntoIterator<Item = ScriptAttribute>,
) -> ExecuteScript
pub fn with_additional_attributes( self, attributes: impl IntoIterator<Item = ScriptAttribute>, ) -> ExecuteScript
Set a list of attributes to add to the script element.
Sourcepub fn set_additional_attributes(
&mut self,
attributes: impl IntoIterator<Item = ScriptAttribute>,
) -> &mut ExecuteScript
pub fn set_additional_attributes( &mut self, attributes: impl IntoIterator<Item = ScriptAttribute>, ) -> &mut ExecuteScript
Set a list of attributes to add to the script element.