PatchSignals

Struct PatchSignals 

pub struct PatchSignals<T = String> {
    pub signals: T,
    pub only_if_missing: bool,
}
PatchSignals patches signals into the signal store

Fields

signals: T

signals is a JavaScript object or JSON string that will be sent to the browser to update signals in the signals.

The data must evaluate to a valid JavaScript. It will be converted to signals by the Datastar client side.

only_if_missing: bool

Whether to merge the signal only if it does not already exist.

If not provided, the Datastar client side will default to false, which will cause the data to be merged into the signals.

Implementations

Source

impl<T> PatchSignals<T>

pub const TYPE: EventType = EventType::PatchSignals

pub fn new(signals: T) -> PatchSignals<T>

Create a new PatchSignals data blob.

pub fn try_into_sse_event( self, ) -> Result<Event<PatchSignals<T>>, EventBuildError>

Consume self as an Event.

pub fn try_into_datastar_event( self, ) -> Result<Event<EventData<T>>, EventBuildError>

Consume self as a super::DatastarEvent.

pub fn with_only_if_missing(self, only_if_missing: bool) -> PatchSignals<T>

Sets whether to merge the signal only if it does not already exist.

pub fn set_only_if_missing( &mut self, only_if_missing: bool, ) -> &mut PatchSignals<T>

Sets whether to merge the signal only if it does not already exist.