pub struct Body(/* private fields */);Expand description
The body type used in rama requests and responses.
Implementations
Sourceimpl Body
impl Body
Sourcepub fn with_limit<B>(body: B, limit: usize) -> Body
pub fn with_limit<B>(body: B, limit: usize) -> Body
Create a new Body with a maximum size limit.
Sourcepub fn from_stream<S>(stream: S) -> Body
pub fn from_stream<S>(stream: S) -> Body
Create a new Body from a Stream.
Sourcepub fn on_drop<F>(self, on_drop: F) -> Body
pub fn on_drop<F>(self, on_drop: F) -> Body
Wrap this body so that on_drop is called if the body is dropped before
being fully consumed (e.g. because the client disconnected mid-response).
The closure fires exactly once and only on early drops — it is disarmed
when StreamingBody::poll_frame returns Poll::Ready(None).
Sourcepub fn with_trailer_headers(self, headers: HeaderMap) -> Body
pub fn with_trailer_headers(self, headers: HeaderMap) -> Body
Attach a headermap as trailer headers to this body.
In case you want this is also available as with_trailer,
provided by a body extension which allows you to use
a Future with as output an option of a result of a headermap.
This method is a shortcut of that function.
Sourcepub fn into_data_stream(self) -> BodyDataStream
pub fn into_data_stream(self) -> BodyDataStream
Convert the body into a Stream of data frames.
Non-data frames (such as trailers) will be discarded. Use http_body_util::BodyStream if
you need a Stream of all frame types.
Sourcepub fn into_event_stream<T>(self) -> EventStream<BodyDataStream, T>where
T: EventDataRead,
pub fn into_event_stream<T>(self) -> EventStream<BodyDataStream, T>where
T: EventDataRead,
Convert the body into a Stream of sse::Events.
https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events.
Sourcepub fn into_json_stream<T>(self) -> JsonReadStream<T, BodyDataStream>where
T: DeserializeOwned,
pub fn into_json_stream<T>(self) -> JsonReadStream<T, BodyDataStream>where
T: DeserializeOwned,
Convert the body into a JsonReadStream.
Stream of json objects, each object separated by a newline (\n).
Sourcepub fn into_json_stream_with_config<T>(
self,
cfg: ParseConfig,
) -> JsonReadStream<T, BodyDataStream>where
T: DeserializeOwned,
pub fn into_json_stream_with_config<T>(
self,
cfg: ParseConfig,
) -> JsonReadStream<T, BodyDataStream>where
T: DeserializeOwned,
Convert the body into a JsonReadStream.
Stream of json objects, each object separated by a newline (\n).
Sourcepub fn into_string_data_event_stream(self) -> EventStream<BodyDataStream>
pub fn into_string_data_event_stream(self) -> EventStream<BodyDataStream>
Convert the body into a Stream of sse::Events with optional string data.
https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events.