pub struct HeaderName { /* private fields */ }Expand description
Represents an HTTP header field name
Header field names identify the header. Header sets may include multiple headers with the same name. The HTTP specification defines a number of standard headers, but HTTP messages may include non-standard header names as well as long as they adhere to the specification.
HeaderName is used as the HeaderMap key. Constants are available for
all standard header names in the header module.
Standard header constants can be used for equality checks. They cannot be
used as const patterns on stable Rust because HeaderName implements
semantic, case-insensitive PartialEq manually. If Rust stabilizes the
structural matching support needed for this representation, these constants
can become pattern-matchable again.
Representation
HeaderName represents standard header names using an enum, as such they
will not require an allocation for storage. Header names preserve their
original casing while equality, ordering and hashing continue to use HTTP’s
case-insensitive header-name semantics.
Implementations
Sourceimpl HeaderName
impl HeaderName
Sourcepub fn from_bytes(src: &[u8]) -> Result<HeaderName, InvalidHeaderName>
pub fn from_bytes(src: &[u8]) -> Result<HeaderName, InvalidHeaderName>
Converts a slice of bytes to an HTTP header name.
This function preserves the original header-name spelling while using HTTP’s case-insensitive semantics for equality and hashing.
Sourcepub fn from_lowercase(src: &[u8]) -> Result<HeaderName, InvalidHeaderName>
pub fn from_lowercase(src: &[u8]) -> Result<HeaderName, InvalidHeaderName>
Converts a slice of bytes to an HTTP header name.
This function expects the input to only contain lowercase characters. This is useful when decoding HTTP/2.0 or HTTP/3.0 headers. Both require that all headers be represented in lower case.
Examples
// Parsing a lower case header
let hdr = HeaderName::from_lowercase(b"content-length").unwrap();
assert_eq!(CONTENT_LENGTH, hdr);
// Parsing a header that contains uppercase characters
assert!(HeaderName::from_lowercase(b"Content-Length").is_err());Sourcepub const fn from_static(src: &'static str) -> HeaderName
pub const fn from_static(src: &'static str) -> HeaderName
Converts a static string to a HTTP header name.
This function preserves the original header-name spelling while using HTTP’s case-insensitive semantics for equality and hashing.
Panics
This function panics when the static string is a invalid header.
Examples
// Parsing a standard header
let hdr = HeaderName::from_static("Content-Length");
assert_eq!(CONTENT_LENGTH, hdr);
// Parsing a custom header
let CUSTOM_HEADER: &'static str = "custom-header";
let a = HeaderName::from_bytes(b"Custom-Header").unwrap();
let b = HeaderName::from_static(CUSTOM_HEADER);
assert_eq!(a, b);// Parsing a header that contains invalid symbols:
HeaderName::from_static("content{}{}length"); // This line panics!Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns a str representation of the header.
Standard headers are returned in their normalized lowercase spelling. Custom headers are returned in their original spelling.
Sourcepub fn as_original_str(&self) -> Cow<'_, str>
pub fn as_original_str(&self) -> Cow<'_, str>
Returns the preserved spelling of the header name.
Standard headers with mixed or uppercase spelling may need to rebuild
their original casing from the compact case mask, so this returns
Cow. For display-only use, prefer Self::display_original.
Sourcepub fn as_lower_str(&self) -> Cow<'_, str>
pub fn as_lower_str(&self) -> Cow<'_, str>
Returns the lowercase spelling of the header name.
This borrows for standard headers and already-lowercase custom headers.
Custom headers with uppercase ASCII letters are lowercased into an owned
string. For display-only use, prefer Self::display_lowercase.
Sourcepub fn display_original(&self) -> OriginalHeaderName<'_>
pub fn display_original(&self) -> OriginalHeaderName<'_>
Returns a display adapter that writes the preserved header spelling.
Sourcepub fn display_lowercase(&self) -> LowercaseHeaderName<'_>
pub fn display_lowercase(&self) -> LowercaseHeaderName<'_>
Returns a display adapter that writes the lowercase header spelling.
This is useful for HTTP/2 and HTTP/3 diagnostics or formatting. It does not allocate.
Sourcepub fn standard(&self) -> Option<StandardHeader>
pub fn standard(&self) -> Option<StandardHeader>
Returns the standard header represented by this name, if this is a standard header.
Sourcepub fn write_original<B>(&self, dst: &mut B)where
B: BufMut,
pub fn write_original<B>(&self, dst: &mut B)where
B: BufMut,
Write the original header spelling represented by this name.
For HTTP/2 and HTTP/3 use Self::write_lowercase instead.
Sourcepub fn write_lowercase<B>(&self, dst: &mut B)where
B: BufMut,
pub fn write_lowercase<B>(&self, dst: &mut B)where
B: BufMut,
Write the lowercase wire representation required by HTTP/2 and HTTP/3.