InfiniteReader

Struct InfiniteReader 

pub struct InfiniteReader { /* private fields */ }
A(n) (in)finite random byte stream implementing AsyncRead.

Cheap to serve, expensive to download. Eat while it’s hot my dear little bots.

Implementations

Source

impl InfiniteReader

pub fn new() -> InfiniteReader

Create an new default InfiniteReader.

pub fn maybe_with_throttle(self, delay: Option<Duration>) -> InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn maybe_set_throttle( &mut self, delay: Option<Duration>, ) -> &mut InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn with_throttle(self, delay: Duration) -> InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn set_throttle(&mut self, delay: Duration) -> &mut InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn without_throttle(self) -> InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn unset_throttle(&mut self) -> &mut InfiniteReader

Define the max throttle to be used for the intervals.

Setting it will ensure that we have randomised throttles between reads, making it more effective.

pub fn maybe_with_size_limit(self, limit: Option<usize>) -> InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn maybe_set_size_limit( &mut self, limit: Option<usize>, ) -> &mut InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn with_size_limit(self, limit: usize) -> InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn set_size_limit(&mut self, limit: usize) -> &mut InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn without_size_limit(self) -> InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn unset_size_limit(&mut self) -> &mut InfiniteReader

Set a limit on how much data will be served, by default it will be an infinite amount of data.

pub fn with_chunk_size(self, size: usize) -> InfiniteReader

Define the chunk size for downloads.

The default value is used if a value of 0 is given.

pub fn set_chunk_size(&mut self, size: usize) -> &mut InfiniteReader

Define the chunk size for downloads.

The default value is used if a value of 0 is given.

pub fn into_body(self) -> Body

Turn this InfiniteReader into a Body.