pub struct Method(/* private fields */);Expand description
The Request Method (VERB)
This type also contains constants for a number of common HTTP methods such as GET, POST, etc.
Currently includes 8 variants representing the 8 methods defined in RFC 7230, plus PATCH (RFC 5789) and QUERY (RFC 10008), and an Extension variant for all extensions.
Examples
use rama_http_types::Method;
assert_eq!(Method::GET, Method::from_bytes(b"GET").unwrap());
assert!(Method::GET.is_idempotent());
assert_eq!(Method::POST.as_str(), "POST");Implementations
Sourceimpl Method
impl Method
Sourcepub const QUERY: Method
pub const QUERY: Method
QUERY
A safe, idempotent, and cacheable method whose request content defines the query, as specified in RFC 10008.
Sourcepub fn from_bytes(src: &[u8]) -> Result<Method, InvalidMethod>
pub fn from_bytes(src: &[u8]) -> Result<Method, InvalidMethod>
Converts a slice of bytes to an HTTP method.
Sourcepub fn is_safe(&self) -> bool
pub fn is_safe(&self) -> bool
Whether a method is considered “safe”, meaning the request is essentially read-only.
See the spec for more words.
Sourcepub fn is_idempotent(&self) -> bool
pub fn is_idempotent(&self) -> bool
Whether a method is considered “idempotent”, meaning the request has the same result if executed multiple times.
See the spec for more words.