pub struct ZipBomb { /* private fields */ }compression only.Expand description
A minimal in-memory ZIP archive that acts as a decompression or resource exhaustion trap.
ZipBomb produces a small, valid ZIP archive that declares
an extremely large uncompressed file,
with no actual payload. When extracted, it causes naive clients or
bots to attempt writing or allocating gigabytes of disk or memory,
despite its tiny compressed size.
This is useful for:
- Honeypots
- Anti-bot traps
- Defensive deception systems
Implementations
Sourceimpl ZipBomb
impl ZipBomb
Sourcepub fn with_depth(self, depth: usize) -> Self
pub fn with_depth(self, depth: usize) -> Self
Overwrite the default depth of the bomb.
Default is used in case the value given is 0.
Sourcepub fn set_depth(&mut self, depth: usize) -> &mut Self
pub fn set_depth(&mut self, depth: usize) -> &mut Self
Overwrite the default depth of the bomb.
Default is used in case the value given is 0.
Sourcepub fn with_fanout(self, fanout: usize) -> Self
pub fn with_fanout(self, fanout: usize) -> Self
Overwrite the default fanout of the bomb.
Default is used in case the value given is 0.
Sourcepub fn set_fanout(&mut self, fanout: usize) -> &mut Self
pub fn set_fanout(&mut self, fanout: usize) -> &mut Self
Overwrite the default fanout of the bomb.
Default is used in case the value given is 0.
Sourcepub fn with_file_size(self, file_size: usize) -> Self
pub fn with_file_size(self, file_size: usize) -> Self
Overwrite the default file size of the leaf files of the bomb.
Default is used in case the value given is 0.
Sourcepub fn set_file_size(&mut self, file_size: usize) -> &mut Self
pub fn set_file_size(&mut self, file_size: usize) -> &mut Self
Overwrite the default file size of the leaf files of the bomb.
Default is used in case the value given is 0.
Sourcepub fn generate_body(&self) -> Body
pub fn generate_body(&self) -> Body
Sourcepub fn generate_response(&self) -> Response
pub fn generate_response(&self) -> Response
Sourcepub fn into_generate_body(self) -> Body
pub fn into_generate_body(self) -> Body
Sourcepub fn into_generate_response(self) -> Response
pub fn into_generate_response(self) -> Response