pub struct Expect(/* private fields */);Expand description
The Expect header.
The “Expect” header field in a request indicates a certain set of behaviors (expectations) that need to be supported by the server in order to properly handle this request. The only such expectation defined by this specification is 100-continue.
Expect = “100-continue”
Example
use rama_http_headers::Expect;
let expect = Expect::CONTINUE;Implementations