pub struct Compression<S, P = DefaultPredicate> { /* private fields */ }compression only.Expand description
Compress response bodies of the underlying service.
This uses the Accept-Encoding header to pick an appropriate encoding and adds the
Content-Encoding header to responses.
See the module docs for more details.
Implementations
Sourceimpl<S> Compression<S, DefaultPredicate>
impl<S> Compression<S, DefaultPredicate>
Sourceimpl<S, P> Compression<S, P>
impl<S, P> Compression<S, P>
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
Sourcepub fn set_gzip(&mut self, enable: bool) -> &mut Self
pub fn set_gzip(&mut self, enable: bool) -> &mut Self
Sets whether to enable the gzip encoding.
Sourcepub fn with_deflate(self, enable: bool) -> Self
pub fn with_deflate(self, enable: bool) -> Self
Sets whether to enable the Deflate encoding.
Sourcepub fn set_deflate(&mut self, enable: bool) -> &mut Self
pub fn set_deflate(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Deflate encoding.
Sourcepub fn set_br(&mut self, enable: bool) -> &mut Self
pub fn set_br(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Brotli encoding.
Sourcepub fn set_zstd(&mut self, enable: bool) -> &mut Self
pub fn set_zstd(&mut self, enable: bool) -> &mut Self
Sets whether to enable the Zstd encoding.
Sourcepub fn with_quality(self, quality: CompressionLevel) -> Self
pub fn with_quality(self, quality: CompressionLevel) -> Self
Sets the compression quality.
Sourcepub fn set_quality(&mut self, quality: CompressionLevel) -> &mut Self
pub fn set_quality(&mut self, quality: CompressionLevel) -> &mut Self
Sets the compression quality.
Sourcepub fn with_respect_content_encoding_if_possible(self) -> Self
pub fn with_respect_content_encoding_if_possible(self) -> Self
Allow responses with content-encoding.
Useful in case your stack uses that response header as preference. Not something you want for regular servers or proxies however, or most use cases for that matter.
Sourcepub fn set_respect_content_encoding_if_possible(&mut self) -> &mut Self
pub fn set_respect_content_encoding_if_possible(&mut self) -> &mut Self
Allow responses with content-encoding.
Useful in case your stack uses that response header as preference. Not something you want for regular servers or proxies however, or most use cases for that matter.
Sourcepub fn with_enforce_not_acceptable(self, enable: bool) -> Self
pub fn with_enforce_not_acceptable(self, enable: bool) -> Self
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.
Sourcepub fn set_enforce_not_acceptable(&mut self, enable: bool) -> &mut Self
pub fn set_enforce_not_acceptable(&mut self, enable: bool) -> &mut Self
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.
Sourcepub fn with_compress_predicate<C>(self, predicate: C) -> Compression<S, C>where
C: Predicate,
pub fn with_compress_predicate<C>(self, predicate: C) -> Compression<S, C>where
C: Predicate,
Replace the current compression predicate.
Predicates are used to determine whether a response should be compressed or not.
The default predicate is DefaultPredicate. See its documentation for more
details on which responses it won’t compress.
Changing the compression predicate
use rama_utils::str::arcstr::arcstr;
use rama_http::layer::compression::{
Compression,
predicate::{Predicate, NotForContentType, DefaultPredicate},
};
use rama_core::service::service_fn;
// Placeholder service_fn
let service = service_fn(async |_: ()| {
Ok::<_, std::io::Error>(rama_http::Response::new(()))
});
// build our custom compression predicate
// its recommended to still include `DefaultPredicate` as part of
// custom predicates
let predicate = DefaultPredicate::new()
// don't compress responses who's `content-type` starts with `application/json`
.and(NotForContentType::new(arcstr!("application/json")));
let service = Compression::new(service).with_compress_predicate(predicate);See predicate for more utilities for building compression predicates.
Responses that are already compressed (ie have a content-encoding header) will never be
recompressed, regardless what they predicate says.