#[non_exhaustive]pub struct DefaultHttpProxyConnectReplyService;Expand description
A default Service which responds on an http (proxy) connect with
a default http response.
It can also be used for other HTTP connect purposes, but that is not what the service is intended for.
Implementations
Sourceimpl DefaultHttpProxyConnectReplyService
impl DefaultHttpProxyConnectReplyService
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DefaultHttpProxyConnectReplyService.