area!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Defines an area inside an image map that has predefined clickable areas. An image map allows geometric areas on an image to be associated with hyperlink.