mark!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents text which is marked or highlighted for reference or notation purposes due to the marked passage’s relevance in the enclosing context.
mark!() { /* proc-macro */ }html only.Represents text which is marked or highlighted for reference or notation purposes due to the marked passage’s relevance in the enclosing context.