style!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Contains style information for a document or part of a document. It contains CSS, which is applied to the contents of the document containing this element.