u!() { /* proc-macro */ }Available on crate feature
html only.Expand description
Represents a span of inline text which should be rendered in a way that indicates that it has a non-textual annotation. This is rendered by default as a single solid underline but may be altered using CSS.