pub struct RedirectStatic<ResBody> { /* private fields */ }Expand description
Service that redirects all requests to a static location.
Implementations
Sourceimpl<ResBody> RedirectStatic<ResBody>
impl<ResBody> RedirectStatic<ResBody>
Sourcepub fn to(loc: impl IntoRedirectLoc) -> Self
pub fn to(loc: impl IntoRedirectLoc) -> Self
Create a new RedirectStatic that uses a 303 See Other status code.
This redirect instructs the client to change the method to GET for the subsequent request
to the given location, which is useful after successful form submission, file upload or when
you generally don’t want the redirected-to page to observe the original request method and
body (if non-empty). If you want to preserve the request method and body,
RedirectStatic::temporary should be used instead.
Sourcepub fn moved(loc: impl IntoRedirectLoc) -> Self
pub fn moved(loc: impl IntoRedirectLoc) -> Self
Create a new found (301) redirect response.
Used if a resource is permanently moved.
Use Self::permanent in case you wish to respect the original HTTP Method.
Sourcepub fn found(loc: impl IntoRedirectLoc) -> Self
pub fn found(loc: impl IntoRedirectLoc) -> Self
Create a new found (302) redirect.
Can be useful in flows where the resource was legit and found, but a pre-requirement such as authentication wasn’t met.
Sourcepub fn temporary(loc: impl IntoRedirectLoc) -> Self
pub fn temporary(loc: impl IntoRedirectLoc) -> Self
Create a new temporary (307) redirect.
Sourcepub fn permanent(loc: impl IntoRedirectLoc) -> Self
pub fn permanent(loc: impl IntoRedirectLoc) -> Self
Create a new permanent (308) redirect.