pub struct InfiniteReader { /* private fields */ }Expand description
A(n) (in)finite random byte stream implementing AsyncRead.
Cheap to serve, expensive to download. Eat while it’s hot my dear little bots.
Implementations
Sourceimpl InfiniteReader
impl InfiniteReader
Sourcepub fn new() -> InfiniteReader
pub fn new() -> InfiniteReader
Create an new default InfiniteReader.
Sourcepub fn maybe_with_throttle(self, delay: Option<Duration>) -> InfiniteReader
pub fn maybe_with_throttle(self, delay: Option<Duration>) -> InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn maybe_set_throttle(
&mut self,
delay: Option<Duration>,
) -> &mut InfiniteReader
pub fn maybe_set_throttle( &mut self, delay: Option<Duration>, ) -> &mut InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn with_throttle(self, delay: Duration) -> InfiniteReader
pub fn with_throttle(self, delay: Duration) -> InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn set_throttle(&mut self, delay: Duration) -> &mut InfiniteReader
pub fn set_throttle(&mut self, delay: Duration) -> &mut InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn without_throttle(self) -> InfiniteReader
pub fn without_throttle(self) -> InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn unset_throttle(&mut self) -> &mut InfiniteReader
pub fn unset_throttle(&mut self) -> &mut InfiniteReader
Define the max throttle to be used for the intervals.
Setting it will ensure that we have randomised throttles between reads, making it more effective.
Sourcepub fn maybe_with_size_limit(self, limit: Option<usize>) -> InfiniteReader
pub fn maybe_with_size_limit(self, limit: Option<usize>) -> InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn maybe_set_size_limit(
&mut self,
limit: Option<usize>,
) -> &mut InfiniteReader
pub fn maybe_set_size_limit( &mut self, limit: Option<usize>, ) -> &mut InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn with_size_limit(self, limit: usize) -> InfiniteReader
pub fn with_size_limit(self, limit: usize) -> InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn set_size_limit(&mut self, limit: usize) -> &mut InfiniteReader
pub fn set_size_limit(&mut self, limit: usize) -> &mut InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn without_size_limit(self) -> InfiniteReader
pub fn without_size_limit(self) -> InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn unset_size_limit(&mut self) -> &mut InfiniteReader
pub fn unset_size_limit(&mut self) -> &mut InfiniteReader
Set a limit on how much data will be served, by default it will be an infinite amount of data.
Sourcepub fn with_chunk_size(self, size: usize) -> InfiniteReader
pub fn with_chunk_size(self, size: usize) -> InfiniteReader
Define the chunk size for downloads.
The default value is used if a value of 0 is given.
Sourcepub fn set_chunk_size(&mut self, size: usize) -> &mut InfiniteReader
pub fn set_chunk_size(&mut self, size: usize) -> &mut InfiniteReader
Define the chunk size for downloads.
The default value is used if a value of 0 is given.
Sourcepub fn into_body(self) -> Body
pub fn into_body(self) -> Body
Turn this InfiniteReader into a Body.